import { Component, EventEmitter, Input, OnChanges, OnInit, Output, SimpleChanges } from '@angular/core';
import { ButtonType } from '../../shared/components/button/buttonType.enum';
import { TypeModal } from '../enums/TypeModal.enum';

@Component({
  selector: 'app-filter-modal',
  templateUrl: './filter-modal.component.html',
  styleUrls: ['./filter-modal.component.scss'],
})
export class FilterModalComponent implements OnInit, OnChanges {
  @Input() public modalType: TypeModal;
  @Input() public filtersTypes: string[];
  @Input() public checkedFilters: string[];
  @Output() searchEvent = new EventEmitter();
  @Output() closeEvent = new EventEmitter();
  public buttonTypeEnum = ButtonType;
  public toggledCategories: string[] = [];
  public currentCheckedFilters: string[] = [];

  ngOnInit(): void {
    this.currentCheckedFilters = [...this.checkedFilters];
  }

  ngOnChanges(changes: SimpleChanges): void {
    if (changes.modalType) this.currentCheckedFilters = [];
  }

  public isFilterChecked(filter: string): boolean {
    return this.currentCheckedFilters.findIndex((_filter) => _filter === filter) > -1;
  }

  public toggleCheckbox(filter: string): void {
    const filterExists = this.currentCheckedFilters.findIndex((_filterChecked) => _filterChecked === filter) !== -1;

    if (!filterExists) {
      const index = this.filtersTypes.findIndex((_filter) => _filter === filter);
      this.currentCheckedFilters.push(this.filtersTypes[index]);
    } else {
      const filterToRemove = this.currentCheckedFilters.findIndex((_filterChecked) => _filterChecked === filter);
      this.currentCheckedFilters.splice(filterToRemove);
    }
  }

  // Clear only filters in the current modal
  public clearFilters(): void {
    this.checkedFilters = [];
    this.currentCheckedFilters = [];
    this.emitModules(this.checkedFilters);
  }

  // Sends an array containing all modules
  public emitModules(filters: string[]): void {
    this.searchEvent.emit(filters);
  }

  public getModalType(): string {
    switch (this.modalType) {
      case TypeModal.employers:
        return 'employers';
      case TypeModal.jobs:
        return 'jobs';
      default:
        return '';
    }
  }

  public closeModal(): void {
    this.closeEvent.emit();
  }

  public onSubmitFilters(): void {
    this.checkedFilters = this.currentCheckedFilters;
    this.emitModules(this.currentCheckedFilters);
  }
}
